package soccerTeamExample_tableVersion;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.TableModel;

public class TeamMemberView extends JPanel implements TeamMemberModelListener {
	private static final boolean DEBUG = true;

	private TeamMemberModel theModel;

	private JTable attributeTable;
	private SoccerPlayerTableModel theModelFromTheWidget;

	private JTextField theMessage;
	private final String MSG_PREFIX = "Summary: ";

	public TeamMemberView(TeamMemberModel model) {
		theModel = model;
		model.addTeamMemberListener(this);

		theModelFromTheWidget = new SoccerPlayerTableModel();
		attributeTable = new JTable(theModelFromTheWidget);
		attributeTable
				.setPreferredScrollableViewportSize(new Dimension(500, 70));
		attributeTable.setFillsViewportHeight(true);
		JScrollPane scrollPane = new JScrollPane(attributeTable);

		if (DEBUG) {
			attributeTable.addMouseListener(new MouseAdapter() {
				public void mouseClicked(MouseEvent e) {
					printDebugData(attributeTable);
				}
			});
		}

		theMessage = new JTextField(MSG_PREFIX, 30);
		theMessage.setEditable(false);

		/**
		 * the JPanel does not have knowledge about the widgets that have been
		 * constructed above. The above widgets are not added into the widget
		 * tree (see p. 17, fig 2.3) unless the add operation has been
		 * specifically invoked. Recall that membership in the window's widget
		 * tree allows the widget to be drawn and to receive events.
		 * 
		 * So we add each of the widgets to this panel's widget tree
		 */
		this.add(scrollPane);
		this.add(theMessage);

	}

	public Dimension getPreferredSize() {
		return new Dimension(700, 300);
	}

	public SoccerPlayerTableModel getModelFromTableWidget() {
		return theModelFromTheWidget;
	}
	
	public JTable getTableWidget() {
		return attributeTable;
	}


	public void setSummaryMessage(String theNewMessage) {
		this.theMessage.setText(MSG_PREFIX + theNewMessage);
	}

	@Override
	public void changed() {
		this.setSummaryMessage(theModel.toString());
	}

	private void printDebugData(JTable table) {
		int numRows = table.getRowCount();
		int numCols = table.getColumnCount();
		javax.swing.table.TableModel model = table.getModel();

		System.out.println("Value of data: ");
		for (int i = 0; i < numRows; i++) {
			System.out.print("    row " + i + ":");
			for (int j = 0; j < numCols; j++) {
				System.out.print("  " + model.getValueAt(i, j));
			}
			System.out.println();
		}
		System.out.println("--------------------------");
	}

}
